Client class

Constructors

Client({String? clientId, String? name, List<ClientAttribute>? attribute, String? createdDateTime, String? createdById})
Client.fromJson(Map<String, dynamic> json)

Properties

attribute List<ClientAttribute>?
getter/setter pair
clientId String?
getter/setter pair
createdById String?
getter/setter pair
createdDateTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited