Networking class

Constructors

Networking()

Properties

apiVer String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pair

Methods

deleteData({String? api, String? path, dynamic body, dynamic headers}) Future<Response>
getData({required String path, dynamic headers}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postData({String? api, String? path, dynamic body, dynamic headers}) Future<Response>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited