AuthRepo class
Constructors
- AuthRepo()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- networking → Networking
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createAccessToken(
{dynamic email, dynamic password}) → Future< Response> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(
{dynamic refreshToken}) → Future< Response> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited