RoleRepo class

Constructors

RoleRepo()

Properties

hashCode int
The hash code for this object.
no setterinherited
networking Networking
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteRole({dynamic accessToken, dynamic roleId}) Future<Response>
getAllRoles({dynamic accessToken}) Future<Response>
getRoleById({dynamic accessToken, dynamic roleId}) Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveRole({dynamic accessToken, dynamic createdById, dynamic roleId, dynamic name, List<RoleAttribute>? attribute}) Future<Response>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited