ClientRepo class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- networking → Networking
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteClient(
{dynamic accessToken, dynamic clientId}) → Future< Response> -
getAllClients(
{dynamic accessToken}) → Future< Response> -
getClientById(
{dynamic accessToken, dynamic clientId}) → Future< Response> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveClient(
{dynamic accessToken, dynamic createdById, dynamic clientId, dynamic name, List< ClientAttribute> ? attribute}) → Future<Response> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited